@@ -105,7 +105,7 @@ around app_build => sub ( $orig, $self ) {
         P->http->get(
             'http://nginx.org/download/nginx-' . $self->nginx_ver . '.tar.gz',
             buf_size    => 1,
-            blocking    => $cv,
+            cv          => $cv,
             on_progress => 1,
             on_finish   => sub ($res) {
                 Archive::Tar->new( $res->body->path, 1, { extract => 1 } );
@@ -118,7 +118,7 @@ around app_build => sub ( $orig, $self ) {
         P->http->get(
             qq[http://nchc.dl.sourceforge.net/project/pcre/pcre/$ENV->{CFG}->{NGINX}->{PCRE_VER}/pcre-$ENV->{CFG}->{NGINX}->{PCRE_VER}.tar.gz],
             buf_size    => 1,
-            blocking    => $cv,
+            cv          => $cv,
             on_progress => 1,
             on_finish   => sub ($res) {
                 Archive::Tar->new( $res->body->path, 1, { extract => 1 } );
@@ -132,7 +132,7 @@ around app_build => sub ( $orig, $self ) {
             P->http->get(
                 $module->{$module_name}->{url},
                 buf_size    => 1,
-                blocking    => $cv,
+                cv          => $cv,
                 on_progress => 1,
                 on_finish   => sub ($res) {
                     my $tar = Archive::Tar->new( $res->body->path );
